==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ToolActionCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionCheckboxDescription } from "./ToolActionCheckboxDescription";
/**
 * @hidden
 */
var ToolActionCheckboxDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionCheckboxDescriptionMetadata, _super);
    function ToolActionCheckboxDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionCheckboxDescriptionMetadata.b = function (a) {
        if (ToolActionCheckboxDescriptionMetadata.a == null) {
            ToolActionCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionCheckboxDescriptionMetadata.c(ToolActionCheckboxDescriptionMetadata.a);
        }
        if (a.k(ToolActionCheckboxDescriptionMetadata.a)) {
            return;
        }
        a.ab(ToolActionCheckboxDescriptionMetadata.a);
    };
    ToolActionCheckboxDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
        a.item("IsChecked", "Boolean");
    };
    ToolActionCheckboxDescriptionMetadata.d = function (a) {
        ToolActionCheckboxDescriptionMetadata.b(a);
        a.ad("ToolActionCheckbox", function () { return new ToolActionCheckboxDescription(); });
        a.ac("ToolActionCheckbox", ToolActionCheckboxDescriptionMetadata.a);
    };
    ToolActionCheckboxDescriptionMetadata.$t = markType(ToolActionCheckboxDescriptionMetadata, 'ToolActionCheckboxDescriptionMetadata');
    ToolActionCheckboxDescriptionMetadata.a = null;
    return ToolActionCheckboxDescriptionMetadata;
}(Base));
export { ToolActionCheckboxDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ToolActionCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionCheckboxDescription } from "./ToolActionCheckboxDescription";
/**
 * @hidden
 */
var ToolActionCheckboxDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionCheckboxDescriptionMetadata, _super);
    function ToolActionCheckboxDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionCheckboxDescriptionMetadata.b = function (a) {
        if (ToolActionCheckboxDescriptionMetadata.a == null) {
            ToolActionCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionCheckboxDescriptionMetadata.c(ToolActionCheckboxDescriptionMetadata.a);
        }
        if (a.k(ToolActionCheckboxDescriptionMetadata.a)) {
            return;
        }
        a.ac(ToolActionCheckboxDescriptionMetadata.a);
    };
    ToolActionCheckboxDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
        a.item("IsChecked", "Boolean");
        a.item("UncheckedBackgroundColor", "Brush");
        a.item("ActualUncheckedBackgroundColor", "Brush");
        a.item("CheckedBackgroundColor", "Brush");
        a.item("ActualCheckedBackgroundColor", "Brush");
        a.item("UncheckedBorderColor", "Brush");
        a.item("ActualUncheckedBorderColor", "Brush");
        a.item("CheckedBorderColor", "Brush");
        a.item("ActualCheckedBorderColor", "Brush");
    };
    ToolActionCheckboxDescriptionMetadata.d = function (a) {
        ToolActionCheckboxDescriptionMetadata.b(a);
        a.ae("ToolActionCheckbox", function () { return new ToolActionCheckboxDescription(); });
        a.ad("ToolActionCheckbox", ToolActionCheckboxDescriptionMetadata.a);
    };
    ToolActionCheckboxDescriptionMetadata.$t = markType(ToolActionCheckboxDescriptionMetadata, 'ToolActionCheckboxDescriptionMetadata');
    ToolActionCheckboxDescriptionMetadata.a = null;
    return ToolActionCheckboxDescriptionMetadata;
}(Base));
export { ToolActionCheckboxDescriptionMetadata };
